@@ -1,4 +1,5 @@
-DEFAULT_G
+DEFAULT_TILE_SIZES = [1, 3, 4]
+
 def get_tile(grid_step, coords, image_input):
     start = tf.cast(tf.math.floor(coords * grid_step))
     end = tf.cast(tf.math.ceil((coords + 1) * grid_step))
